@@ -3,6 +3,7 @@ from .admin import Admin
 from .dashboard import Dashboard
 from .datasource import Datasource
 from .folder import Folder
-from .organisation import Organisation, Organisations
+from .organization import Organization, Organizations
 from .search import Search
 from .user import User, Users
+from .team import Teams
